@@ -104,10 +104,16 @@ class H2ORuleFitMOJOModel(H2OSupervisedMOJOModelParams, HasIgnoredColsOnMOJO):
         return value
 
 
+    def getMaxCategoricalLevels(self):
+        value = self._java_obj.getMaxCategoricalLevels()
+        return value
+
+
     def getAucType(self):
         value = self._java_obj.getAucType()
         return value
 
+    # Outputs
 
     def getRuleImportance(self):
         value = self._java_obj.getRuleImportance()
