@@ -27,6 +27,7 @@ from ai.h2o.sparkling.ml.models.H2OPCAMOJOModel import H2OPCAMOJOModel
 from ai.h2o.sparkling.ml.models.H2OGLRMMOJOModel import H2OGLRMMOJOModel
 from ai.h2o.sparkling.ml.models.H2ODeepLearningMOJOModel import H2ODeepLearningMOJOModel
 from ai.h2o.sparkling.ml.models.H2OAutoEncoderMOJOModel import H2OAutoEncoderMOJOModel
+from ai.h2o.sparkling.ml.models.H2OWord2VecMOJOModel import H2OWord2VecMOJOModel
 from ai.h2o.sparkling.ml.models.H2OKMeansMOJOModel import H2OKMeansMOJOModel
 from ai.h2o.sparkling.ml.models.H2OIsolationForestMOJOModel import H2OIsolationForestMOJOModel
 from ai.h2o.sparkling.ml.models.H2OMOJOPipelineModel import H2OMOJOPipelineModel
@@ -40,3 +41,4 @@ from ai.h2o.sparkling.ml.models.H2OMOJOModel import H2OAlgorithmMOJOModel
 from ai.h2o.sparkling.ml.models.H2OMOJOModel import H2OFeatureMOJOModel
 from ai.h2o.sparkling.ml.models.H2OCoxPHMOJOModel import H2OCoxPHMOJOModel
 from ai.h2o.sparkling.ml.models.H2ORuleFitMOJOModel import H2ORuleFitMOJOModel
+from ai.h2o.sparkling.ml.models.H2OStackedEnsembleMOJOModel import H2OStackedEnsembleMOJOModel
